Github: https://github.com/p-d-h/abbts_blp  
Installation: pip install abbts_blp (https://pypi.org/project/abbts-blp/)  
Dokumentation: https://raw.githack.com/p-d-h/abbts_blp/main/docs/build/html/index.html
